@@ -26,6 +26,8 @@
 #include <klineedit.h>
 
 #include <QUrl>
+#include <QPointer>
+#include <QMenu>
 
 class KComboBoxPrivate
 {
@@ -54,12 +56,6 @@ public:
 void KComboBoxPrivate::init()
 {
     Q_Q(KComboBox);
-    q->setCompleter(nullptr);
-    q->QComboBox::setAutoCompletion(false); // otherwise setLineEdit will create a completer...
-
-    if (q->isEditable()) {
-        q->lineEdit()->setContextMenuPolicy(Qt::DefaultContextMenu);
-    }
 }
 
 void KComboBoxPrivate::_k_lineEditDeleted()
@@ -137,7 +133,7 @@ bool KComboBox::autoCompletion() const
     return completionMode() == KCompletion::CompletionAuto;
 }
 
-#ifndef KCOMPLETION_NO_DEPRECATED
+#if KCOMPLETION_BUILD_DEPRECATED_SINCE(4, 5)
 void KComboBox::setContextMenuEnabled(bool showMenu)
 {
     Q_D(KComboBox);
@@ -145,7 +141,9 @@ void KComboBox::setContextMenuEnabled(bool showMenu)
         d->klineEdit->setContextMenuPolicy(showMenu ? Qt::DefaultContextMenu : Qt::NoContextMenu);
     }
 }
+#endif
 
+#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 0)
 void KComboBox::setUrlDropsEnabled(bool enable)
 {
     Q_D(KComboBox);
@@ -303,7 +301,7 @@ void KComboBox::setLineEdit(QLineEdit *edit)
         KLineEdit *kedit = new KLineEdit(this);
 
         if (isEditable()) {
-            kedit->setClearButtonShown(true);
+            kedit->setClearButtonEnabled(true);
         }
 
         edit = kedit;
@@ -314,6 +312,7 @@ void KComboBox::setLineEdit(QLineEdit *edit)
     QPointer<KCompletion> completion = compObj();
 
     QComboBox::setLineEdit(edit);
+    edit->setCompleter(nullptr); // remove Qt's builtin completer (set by setLineEdit), we have our own
     d->klineEdit = qobject_cast<KLineEdit *>(edit);
     setDelegate(d->klineEdit);
 
@@ -323,7 +322,8 @@ void KComboBox::setLineEdit(QLineEdit *edit)
 
     // Connect the returnPressed signal for both Q[K]LineEdits'
     if (edit) {
-        connect(edit, SIGNAL(returnPressed()), SIGNAL(returnPressed()));
+        connect(edit, QOverload<>::of(&QLineEdit::returnPressed),
+                this, QOverload<>::of(&KComboBox::returnPressed));
     }
 
     if (d->klineEdit) {
@@ -333,30 +333,37 @@ void KComboBox::setLineEdit(QLineEdit *edit)
         // when it is a KLineEdit!
         connect(edit, SIGNAL(destroyed()), SLOT(_k_lineEditDeleted()));
 
-        connect(d->klineEdit, SIGNAL(returnPressed(QString)),
-                SIGNAL(returnPressed(QString)));
+        connect(d->klineEdit, QOverload<const QString&>::of(&KLineEdit::returnPressed),
+                this, QOverload<const QString&>::of(&KComboBox::returnPressed));
 
-        connect(d->klineEdit, SIGNAL(completion(QString)),
-                SIGNAL(completion(QString)));
+        connect(d->klineEdit, &KLineEdit::completion,
+                this, &KComboBox::completion);
 
-        connect(d->klineEdit, SIGNAL(substringCompletion(QString)),
-                SIGNAL(substringCompletion(QString)));
+        connect(d->klineEdit, &KLineEdit::substringCompletion,
+                this, &KComboBox::substringCompletion);
 
-        connect(d->klineEdit,
-                SIGNAL(textRotation(KCompletionBase::KeyBindingType)),
-                SIGNAL(textRotation(KCompletionBase::KeyBindingType)));
+        connect(d->klineEdit, &KLineEdit::textRotation,
+                this, &KComboBox::textRotation);
 
-        connect(d->klineEdit,
-                SIGNAL(completionModeChanged(KCompletion::CompletionMode)),
-                SIGNAL(completionModeChanged(KCompletion::CompletionMode)));
+        connect(d->klineEdit, &KLineEdit::completionModeChanged,
+                this, &KComboBox::completionModeChanged);
 
-        connect(d->klineEdit,
-                SIGNAL(aboutToShowContextMenu(QMenu*)),
-                SIGNAL(aboutToShowContextMenu(QMenu*)));
+        connect(d->klineEdit, &KLineEdit::aboutToShowContextMenu,
+                this, &KComboBox::aboutToShowContextMenu);
 
-        connect(d->klineEdit,
-                SIGNAL(completionBoxActivated(QString)),
-                SIGNAL(activated(QString)));
+        // match the declaration of the deprecated signal
+#if QT_DEPRECATED_SINCE(5, 15) || QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
+        connect(d->klineEdit, &KLineEdit::completionBoxActivated,
+                this, QOverload<const QString&>::of(&QComboBox::activated));
+QT_WARNING_POP
+#endif
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+        connect(d->klineEdit, &KLineEdit::completionBoxActivated,
+                this, QOverload<const QString&>::of(&QComboBox::textActivated));
+#endif
 
         d->klineEdit->setTrapReturnKey(d->trapReturnKey);
     }
@@ -397,7 +404,7 @@ void KComboBox::setEditable(bool editable)
         // Compared to QComboBox::setEditable, we might be missing the SH_ComboBox_Popup code though...
         // If a style needs this, then we'll need to call QComboBox::setEditable and then setLineEdit again
         KLineEdit *edit = new KLineEdit(this);
-        edit->setClearButtonShown(true);
+        edit->setClearButtonEnabled(true);
         setLineEdit(edit);
     } else {
         QComboBox::setEditable(editable);
